@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2019 Cppcheck team.
+ * Copyright (C) 2007-2020 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -72,14 +72,16 @@ public:
     void reportOut(const std::string &outmsg) OVERRIDE;
 
     /** xml output of errors */
-    void reportErr(const ErrorLogger::ErrorMessage &msg) OVERRIDE;
+    void reportErr(const ErrorMessage &msg) OVERRIDE;
 
     void reportProgress(const std::string &filename, const char stage[], const std::size_t value) OVERRIDE;
 
     /**
      * Output information messages.
      */
-    void reportInfo(const ErrorLogger::ErrorMessage &msg) OVERRIDE;
+    void reportInfo(const ErrorMessage &msg) OVERRIDE;
+
+    void bughuntingReport(const std::string &str) OVERRIDE;
 
     /**
      * Information about how many files have been checked
@@ -106,6 +108,11 @@ public:
     */
     static bool tryLoadLibrary(Library& destination, const char* basepath, const char* filename);
 
+    /**
+     * Execute a shell command and read the output from it. Returns true if command terminated successfully.
+     */
+    static bool executeCommand(std::string exe, std::vector<std::string> args, std::string redirect, std::string *output);
+
 protected:
 
     /**
@@ -187,6 +194,11 @@ private:
      */
     std::ofstream *mErrorOutput;
 
+    /**
+     * Bug hunting report
+     */
+    std::ostream *mBugHuntingReport;
+
     /**
      * Has --errorlist been given?
      */
