@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2019 Cppcheck team.
+ * Copyright (C) 2007-2020 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -64,7 +64,7 @@ static BOOL myFileExists(const std::string& path)
     if (fa != INVALID_FILE_ATTRIBUTES && !(fa & FILE_ATTRIBUTE_DIRECTORY))
         result = TRUE;
 #else
-    const BOOL result = PathFileExistsA(path.c_str());
+    const BOOL result = PathFileExistsA(path.c_str()) && !PathIsDirectoryA(path.c_str());
 #endif
     return result;
 }
@@ -189,12 +189,26 @@ static void addFiles2(std::map<std::string, std::size_t> &files,
             if (!dir)
                 return;
 
-            dirent entry;
             dirent * dir_result;
+            // make sure we reserve enough space for the readdir_r() buffer;
+            // according to POSIX:
+            //   The storage pointed to by entry shall be large enough for a
+            //   dirent with an array of char d_name members containing at
+            //   least {NAME_MAX}+1 elements.
+            // on some platforms, d_name is not a static sized-array but
+            // a pointer to space usually reserved right after the dirent
+            // struct; the union here allows to reserve the space and to
+            // provide a pointer to the right type that can be passed where
+            // needed without casts
+            union {
+                dirent entry;
+                char buf[sizeof(*dir_result) + (sizeof(dir_result->d_name) > 1 ? 0 : NAME_MAX + 1)];
+            } dir_result_buffer;
+            UNUSED(dir_result_buffer.buf); // do not trigger cppcheck itself on the "unused buf"
             std::string new_path;
             new_path.reserve(path.length() + 100);// prealloc some memory to avoid constant new/deletes in loop
 
-            while ((readdir_r(dir, &entry, &dir_result) == 0) && (dir_result != nullptr)) {
+            while ((readdir_r(dir, &dir_result_buffer.entry, &dir_result) == 0) && (dir_result != nullptr)) {
 
                 if ((std::strcmp(dir_result->d_name, ".") == 0) ||
                     (std::strcmp(dir_result->d_name, "..") == 0))
