@@ -182,7 +182,7 @@ unsigned int ThreadExecutor::check()
     std::list<ImportProject::FileSettings>::const_iterator iFileSettings = mSettings.project.fileSettings.begin();
     for (;;) {
         // Start a new child
-        size_t nchildren = rpipes.size();
+        size_t nchildren = childFile.size();
         if ((iFile != mFiles.end() || iFileSettings != mSettings.project.fileSettings.end()) && nchildren < mSettings.jobs && checkLoadAverage(nchildren)) {
             int pipes[2];
             if (pipe(pipes) == -1) {
@@ -244,7 +244,8 @@ unsigned int ThreadExecutor::check()
                 pipeFile[pipes[0]] = iFile->first;
                 ++iFile;
             }
-        } else if (!rpipes.empty()) {
+        }
+        if (!rpipes.empty()) {
             fd_set rfds;
             FD_ZERO(&rfds);
             for (std::list<int>::const_iterator rp = rpipes.begin(); rp != rpipes.end(); ++rp)
@@ -284,7 +285,8 @@ unsigned int ThreadExecutor::check()
                         ++rp;
                 }
             }
-
+        }
+        if (!childFile.empty()) {
             int stat = 0;
             pid_t child = waitpid(0, &stat, WNOHANG);
             if (child > 0) {
@@ -295,24 +297,21 @@ unsigned int ThreadExecutor::check()
                     childFile.erase(c);
                 }
 
-                if (WIFSIGNALED(stat)) {
+                if (WIFEXITED(stat)) {
+                    const int exitstaus = WEXITSTATUS(stat);
+                    if (exitstaus != 0) {
+                        std::ostringstream oss;
+                        oss << "Child process exited with " << exitstaus;
+                        reportInternalChildErr(childname, oss.str());
+                    }
+                } else if (WIFSIGNALED(stat)) {
                     std::ostringstream oss;
-                    oss << "Internal error: Child process crashed with signal " << WTERMSIG(stat);
-
-                    std::list<ErrorMessage::FileLocation> locations;
-                    locations.emplace_back(childname, 0, 0);
-                    const ErrorMessage errmsg(locations,
-                                              emptyString,
-                                              Severity::error,
-                                              oss.str(),
-                                              "cppcheckError",
-                                              false);
-
-                    if (!mSettings.nomsg.isSuppressed(errmsg.toSuppressionsErrorMessage()))
-                        mErrorLogger.reportErr(errmsg);
+                    oss << "Child process crashed with signal " << WTERMSIG(stat);
+                    reportInternalChildErr(childname, oss.str());
                 }
             }
-        } else {
+        }
+        if (iFile == mFiles.end() && iFileSettings == mSettings.project.fileSettings.end() && rpipes.empty() && childFile.empty()) {
             // All done
             break;
         }
@@ -359,6 +358,21 @@ void ThreadExecutor::bughuntingReport(const std::string &str)
     writeToPipe(REPORT_VERIFICATION, str.c_str());
 }
 
+void ThreadExecutor::reportInternalChildErr(const std::string &childname, const std::string &msg)
+{
+    std::list<ErrorMessage::FileLocation> locations;
+    locations.emplace_back(childname, 0, 0);
+    const ErrorMessage errmsg(locations,
+                              emptyString,
+                              Severity::error,
+                              "Internal error: " + msg,
+                              "cppcheckError",
+                              false);
+
+    if (!mSettings.nomsg.isSuppressed(errmsg.toSuppressionsErrorMessage()))
+        mErrorLogger.reportErr(errmsg);
+}
+
 #elif defined(THREADING_MODEL_WIN)
 
 void ThreadExecutor::addFileContent(const std::string &path, const std::string &content)
