@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2019 Cppcheck team.
+ * Copyright (C) 2007-2020 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "codeeditor.h"
 #include "codeeditstyledialog.h"
+#include "codeeditstylecontrols.h"
 #include <QHBoxLayout>
 #include <QVBoxLayout>
 #include <QFormLayout>
