@@ -34,31 +34,26 @@
 #include "applicationlist.h"
 #include "aboutdialog.h"
 #include "common.h"
-#include "threadhandler.h"
+#include "filelist.h"
 #include "fileviewdialog.h"
 #include "functioncontractdialog.h"
+#include "helpdialog.h"
+#include "librarydialog.h"
 #include "projectfile.h"
 #include "projectfiledialog.h"
 #include "report.h"
 #include "scratchpad.h"
+#include "showtypes.h"
 #include "statsdialog.h"
 #include "settingsdialog.h"
+#include "threadhandler.h"
 #include "threadresult.h"
 #include "translationhandler.h"
-#include "filelist.h"
-#include "showtypes.h"
-#include "librarydialog.h"
+#include "variablecontractsdialog.h"
 
 static const QString OnlineHelpURL("http://cppcheck.net/manual.html");
 static const QString compile_commands_json("compile_commands.json");
 
-static QString getDataDir(const QSettings *settings)
-{
-    const QString dataDir = settings->value("DATADIR", QString()).toString();
-    const QString appPath = QFileInfo(QCoreApplication::applicationFilePath()).canonicalPath();
-    return dataDir.isEmpty() ? appPath : dataDir;
-}
-
 MainWindow::MainWindow(TranslationHandler* th, QSettings* settings) :
     mSettings(settings),
     mApplications(new ApplicationList(this)),
@@ -74,7 +69,7 @@ MainWindow::MainWindow(TranslationHandler* th, QSettings* settings) :
 {
     mUI.setupUi(this);
     mThread = new ThreadHandler(this);
-    mThread->setDataDir(getDataDir(settings));
+    mThread->setDataDir(getDataDir());
     mUI.mResults->initialize(mSettings, mApplications, mThread);
 
     // Filter timer to delay filtering results slightly while typing
@@ -141,9 +136,11 @@ MainWindow::MainWindow(TranslationHandler* th, QSettings* settings) :
     connect(mUI.mResults, &ResultsView::gotResults, this, &MainWindow::resultsAdded);
     connect(mUI.mResults, &ResultsView::resultsHidden, mUI.mActionShowHidden, &QAction::setEnabled);
     connect(mUI.mResults, &ResultsView::checkSelected, this, &MainWindow::performSelectedFilesCheck);
-    connect(mUI.mResults, &ResultsView::tagged, this, &MainWindow::tagged);
     connect(mUI.mResults, &ResultsView::suppressIds, this, &MainWindow::suppressIds);
     connect(mUI.mResults, &ResultsView::editFunctionContract, this, &MainWindow::editFunctionContract);
+    connect(mUI.mResults, &ResultsView::editVariableContract, this, &MainWindow::editVariableContract);
+    connect(mUI.mResults, &ResultsView::deleteFunctionContract, this, &MainWindow::deleteFunctionContract);
+    connect(mUI.mResults, &ResultsView::deleteVariableContract, this, &MainWindow::deleteVariableContract);
     connect(mUI.mMenuView, &QMenu::aboutToShow, this, &MainWindow::aboutToShowViewMenu);
 
     // File menu
@@ -341,13 +338,15 @@ void MainWindow::loadSettings()
         if (inf.exists() && inf.isReadable()) {
             setPath(SETTINGS_LAST_PROJECT_PATH, projectFile);
             mProjectFile = new ProjectFile(this);
+            mProjectFile->setActiveProject();
             mProjectFile->read(projectFile);
             loadLastResults();
             QDir::setCurrent(inf.absolutePath());
         }
     }
 
-    updateContractsTab();
+    updateFunctionContractsTab();
+    updateVariableContractsTab();
 }
 
 void MainWindow::saveSettings() const
@@ -607,15 +606,31 @@ QStringList MainWindow::selectFilesToAnalyze(QFileDialog::FileMode mode)
     return selected;
 }
 
-void MainWindow::updateContractsTab()
+void MainWindow::updateFunctionContractsTab()
 {
     QStringList addedContracts;
     if (mProjectFile) {
-        for (const auto it: mProjectFile->getFunctionContracts()) {
+        for (const auto& it: mProjectFile->getFunctionContracts()) {
             addedContracts << QString::fromStdString(it.first);
         }
     }
-    mUI.mResults->setAddedContracts(addedContracts);
+    mUI.mResults->setAddedFunctionContracts(addedContracts);
+}
+
+void MainWindow::updateVariableContractsTab()
+{
+    QStringList added;
+    if (mProjectFile) {
+        for (auto vc: mProjectFile->getVariableContracts()) {
+            QString line = vc.first;
+            if (!vc.second.minValue.empty())
+                line += " min:" + QString::fromStdString(vc.second.minValue);
+            if (!vc.second.maxValue.empty())
+                line += " max:" + QString::fromStdString(vc.second.maxValue);
+            added << line;
+        }
+    }
+    mUI.mResults->setAddedVariableContracts(added);
 }
 
 void MainWindow::analyzeFiles()
@@ -764,7 +779,7 @@ Library::Error MainWindow::loadLibrary(Library *library, const QString &filename
 #endif
 
     // Try to load the library from the cfg subfolder..
-    const QString datadir = mSettings->value("DATADIR", QString()).toString();
+    const QString datadir = getDataDir();
     if (!datadir.isEmpty()) {
         ret = library->load(nullptr, (datadir+"/"+filename).toLatin1());
         if (ret.errorcode != Library::ErrorCode::FILE_NOT_FOUND)
@@ -861,6 +876,9 @@ Settings MainWindow::getCppcheckSettings()
 
         result.functionContracts = mProjectFile->getFunctionContracts();
 
+        for (const auto& vc: mProjectFile->getVariableContracts())
+            result.variableContracts[vc.first.toStdString()] = vc.second;
+
         const QStringList undefines = mProjectFile->getUndefines();
         foreach (QString undefine, undefines)
             result.userUndefs.insert(undefine.toStdString());
@@ -908,6 +926,7 @@ Settings MainWindow::getCppcheckSettings()
         }
 
         result.maxCtuDepth = mProjectFile->getMaxCtuDepth();
+        result.maxTemplateRecursion = mProjectFile->getMaxTemplateRecursion();
         result.checkHeaders = mProjectFile->getCheckHeaders();
         result.checkUnusedTemplates = mProjectFile->getCheckUnusedTemplates();
         result.safeChecks.classes = mProjectFile->safeChecks.classes;
@@ -917,7 +936,7 @@ Settings MainWindow::getCppcheckSettings()
         foreach (QString s, mProjectFile->getCheckUnknownFunctionReturn())
             result.checkUnknownFunctionReturn.insert(s.toStdString());
 
-        QString filesDir(getDataDir(mSettings));
+        QString filesDir(getDataDir());
         const QString pythonCmd = mSettings->value(SETTINGS_PYTHON_PATH).toString();
         foreach (QString addon, mProjectFile->getAddons()) {
             QString addonFilePath = ProjectFile::getAddonFilePath(filesDir, addon);
@@ -1023,9 +1042,9 @@ void MainWindow::analysisDone()
 
     enableResultsButtons();
 
-    for (int i = 0; i < MaxRecentProjects + 1; i++) {
-        if (mRecentProjectActs[i] != nullptr)
-            mRecentProjectActs[i]->setEnabled(true);
+    for (QAction* recentProjectAct : mRecentProjectActs) {
+        if (recentProjectAct != nullptr)
+            recentProjectAct->setEnabled(true);
     }
 
     // Notify user - if the window is not active - that check is ready
@@ -1049,9 +1068,9 @@ void MainWindow::checkLockDownUI()
     if (mScratchPad)
         mScratchPad->setEnabled(false);
 
-    for (int i = 0; i < MaxRecentProjects + 1; i++) {
-        if (mRecentProjectActs[i] != nullptr)
-            mRecentProjectActs[i]->setEnabled(false);
+    for (QAction* recentProjectAct : mRecentProjectActs) {
+        if (recentProjectAct != nullptr)
+            recentProjectAct->setEnabled(false);
     }
 }
 
@@ -1464,7 +1483,8 @@ void MainWindow::openHelpContents()
 
 void MainWindow::openOnlineHelp()
 {
-    QDesktopServices::openUrl(QUrl(OnlineHelpURL));
+    HelpDialog *helpDialog = new HelpDialog;
+    helpDialog->showMaximized();
 }
 
 void MainWindow::openProjectFile()
@@ -1507,7 +1527,10 @@ void MainWindow::loadProjectFile(const QString &filePath)
     mUI.mActionEditProjectFile->setEnabled(true);
     delete mProjectFile;
     mProjectFile = new ProjectFile(filePath, this);
-    updateContractsTab();
+    mProjectFile->setActiveProject();
+    mUI.mResults->showContracts(mProjectFile->bugHunting);
+    updateFunctionContractsTab();
+    updateVariableContractsTab();
     if (!loadLastResults())
         analyzeProject(mProjectFile);
 }
@@ -1521,8 +1544,6 @@ QString MainWindow::getLastResults() const
 
 bool MainWindow::loadLastResults()
 {
-    if (mProjectFile)
-        mUI.mResults->setTags(mProjectFile->getTags());
     const QString &lastResults = getLastResults();
     if (lastResults.isEmpty())
         return false;
@@ -1545,7 +1566,6 @@ void MainWindow::analyzeProject(const ProjectFile *projectFile, const bool check
     QDir::setCurrent(inf.absolutePath());
 
     mThread->setAddonsAndTools(projectFile->getAddonsAndTools());
-    mUI.mResults->setTags(projectFile->getTags());
 
     // If the root path is not given or is not "current dir", use project
     // file's location directory as root path
@@ -1629,18 +1649,21 @@ void MainWindow::newProjectFile()
 
     delete mProjectFile;
     mProjectFile = new ProjectFile(this);
+    mProjectFile->setActiveProject();
     mProjectFile->setFilename(filepath);
     mProjectFile->setBuildDir(filename.left(filename.indexOf(".")) + "-cppcheck-build-dir");
 
     ProjectFileDialog dlg(mProjectFile, this);
     if (dlg.exec() == QDialog::Accepted) {
         addProjectMRU(filepath);
+        mUI.mResults->showContracts(mProjectFile->bugHunting);
         analyzeProject(mProjectFile);
     } else {
         closeProjectFile();
     }
 
-    updateContractsTab();
+    updateFunctionContractsTab();
+    updateVariableContractsTab();
 }
 
 void MainWindow::closeProjectFile()
@@ -1648,7 +1671,8 @@ void MainWindow::closeProjectFile()
     delete mProjectFile;
     mProjectFile = nullptr;
     mUI.mResults->clear(true);
-    mUI.mResults->setTags(QStringList());
+    mUI.mResults->clearContracts();
+    mUI.mResults->showContracts(false);
     enableProjectActions(false);
     enableProjectOpenActions(true);
     formatAndSetTitle();
@@ -1669,6 +1693,7 @@ void MainWindow::editProjectFile()
     ProjectFileDialog dlg(mProjectFile, this);
     if (dlg.exec() == QDialog::Accepted) {
         mProjectFile->write();
+        mUI.mResults->showContracts(mProjectFile->bugHunting);
         analyzeProject(mProjectFile);
     }
 }
@@ -1747,9 +1772,9 @@ void MainWindow::openRecentProject()
 
 void MainWindow::updateMRUMenuItems()
 {
-    for (int i = 0; i < MaxRecentProjects + 1; i++) {
-        if (mRecentProjectActs[i] != nullptr)
-            mUI.mMenuFile->removeAction(mRecentProjectActs[i]);
+    for (QAction* recentProjectAct : mRecentProjectActs) {
+        if (recentProjectAct != nullptr)
+            mUI.mMenuFile->removeAction(recentProjectAct);
     }
 
     QStringList projects = mSettings->value(SETTINGS_MRU_PROJECTS).toStringList();
@@ -1810,13 +1835,6 @@ void MainWindow::selectPlatform()
     }
 }
 
-void MainWindow::tagged()
-{
-    const QString &lastResults = getLastResults();
-    if (!lastResults.isEmpty())
-        mUI.mResults->save(lastResults, Report::XMLV2);
-}
-
 void MainWindow::suppressIds(QStringList ids)
 {
     if (!mProjectFile)
@@ -1862,5 +1880,35 @@ void MainWindow::editFunctionContract(QString function)
         mProjectFile->write();
     }
 
-    updateContractsTab();
+    updateFunctionContractsTab();
+}
+
+void MainWindow::editVariableContract(QString var)
+{
+    if (!mProjectFile)
+        return;
+
+    VariableContractsDialog dlg(nullptr, var);
+    if (dlg.exec() == QDialog::Accepted) {
+        mProjectFile->setVariableContracts(dlg.getVarname(), dlg.getMin(), dlg.getMax());
+        mProjectFile->write();
+    }
+
+    updateVariableContractsTab();
+}
+
+void MainWindow::deleteFunctionContract(QString function)
+{
+    if (mProjectFile) {
+        mProjectFile->deleteFunctionContract(function);
+        mProjectFile->write();
+    }
+}
+
+void MainWindow::deleteVariableContract(QString var)
+{
+    if (mProjectFile) {
+        mProjectFile->deleteVariableContract(var);
+        mProjectFile->write();
+    }
 }
