@@ -62,6 +62,8 @@ static const int numberOfBuiltinPlatforms = sizeof(builtinPlatforms) / sizeof(bu
 
 QStringList ProjectFileDialog::getProjectConfigs(const QString &fileName)
 {
+    if (!fileName.endsWith(".sln") && !fileName.endsWith(".vcxproj"))
+        return QStringList();
     QStringList ret;
     ImportProject importer;
     Settings projSettings;
@@ -88,8 +90,7 @@ ProjectFileDialog::ProjectFileDialog(ProjectFile *projectFile, QWidget *parent)
     // Checkboxes for the libraries..
     const QString applicationFilePath = QCoreApplication::applicationFilePath();
     const QString appPath = QFileInfo(applicationFilePath).canonicalPath();
-    QSettings settings;
-    const QString datadir = settings.value("DATADIR",QString()).toString();
+    const QString datadir = getDataDir();
     QStringList searchPaths;
     searchPaths << appPath << appPath + "/cfg" << inf.canonicalPath();
 #ifdef FILESDIR
@@ -159,8 +160,8 @@ ProjectFileDialog::ProjectFileDialog(ProjectFile *projectFile, QWidget *parent)
 
     // Platforms..
     Platforms platforms;
-    for (int i = 0; i < numberOfBuiltinPlatforms; i++)
-        mUI.mComboBoxPlatform->addItem(platforms.get(builtinPlatforms[i]).mTitle);
+    for (cppcheck::Platform::PlatformType builtinPlatform : builtinPlatforms)
+        mUI.mComboBoxPlatform->addItem(platforms.get(builtinPlatform).mTitle);
     QStringList platformFiles;
     foreach (QString sp, searchPaths) {
         if (sp.endsWith("/cfg"))
@@ -199,6 +200,7 @@ ProjectFileDialog::ProjectFileDialog(ProjectFile *projectFile, QWidget *parent)
     connect(mUI.mBtnEditInclude, &QPushButton::clicked, this, &ProjectFileDialog::editIncludeDir);
     connect(mUI.mBtnRemoveInclude, &QPushButton::clicked, this, &ProjectFileDialog::removeIncludeDir);
     connect(mUI.mBtnAddIgnorePath, SIGNAL(clicked()), this, SLOT(addExcludePath()));
+    connect(mUI.mBtnAddIgnoreFile, SIGNAL(clicked()), this, SLOT(addExcludeFile()));
     connect(mUI.mBtnEditIgnorePath, &QPushButton::clicked, this, &ProjectFileDialog::editExcludePath);
     connect(mUI.mBtnRemoveIgnorePath, &QPushButton::clicked, this, &ProjectFileDialog::removeExcludePath);
     connect(mUI.mBtnIncludeUp, &QPushButton::clicked, this, &ProjectFileDialog::moveIncludePathUp);
@@ -208,6 +210,7 @@ ProjectFileDialog::ProjectFileDialog(ProjectFile *projectFile, QWidget *parent)
     connect(mUI.mListSuppressions, &QListWidget::doubleClicked, this, &ProjectFileDialog::editSuppression);
     connect(mUI.mBtnBrowseMisraFile, &QPushButton::clicked, this, &ProjectFileDialog::browseMisraFile);
     connect(mUI.mChkAllVsConfigs, &QCheckBox::clicked, this, &ProjectFileDialog::checkAllVSConfigs);
+    connect(mUI.mBtnNormalAnalysis, &QCheckBox::toggled, mUI.mBtnSafeClasses, &QCheckBox::setEnabled);
     loadFromProjectFile(projectFile);
 }
 
@@ -242,8 +245,12 @@ static void updateAddonCheckBox(QCheckBox *cb, const ProjectFile *projectFile, c
 
 void ProjectFileDialog::checkAllVSConfigs()
 {
-    if (mUI.mChkAllVsConfigs->isChecked())
-        mUI.mListVsConfigs->selectAll();
+    if (mUI.mChkAllVsConfigs->isChecked()) {
+        for (int row = 0; row < mUI.mListVsConfigs->count(); ++row) {
+            QListWidgetItem *item = mUI.mListVsConfigs->item(row);
+            item->setCheckState(Qt::Checked);
+        }
+    }
     mUI.mListVsConfigs->setEnabled(!mUI.mChkAllVsConfigs->isChecked());
 }
 
@@ -257,15 +264,24 @@ void ProjectFileDialog::loadFromProjectFile(const ProjectFile *projectFile)
     setCheckPaths(projectFile->getCheckPaths());
     setImportProject(projectFile->getImportProject());
     mUI.mChkAllVsConfigs->setChecked(projectFile->getAnalyzeAllVsConfigs());
+    setProjectConfigurations(getProjectConfigs(mUI.mEditImportProject->text()));
+    for (int row = 0; row < mUI.mListVsConfigs->count(); ++row) {
+        QListWidgetItem *item = mUI.mListVsConfigs->item(row);
+        if (projectFile->getAnalyzeAllVsConfigs() || projectFile->getVsConfigurations().contains(item->text()))
+            item->setCheckState(Qt::Checked);
+        else
+            item->setCheckState(Qt::Unchecked);
+    }
     mUI.mCheckHeaders->setChecked(projectFile->getCheckHeaders());
     mUI.mCheckUnusedTemplates->setChecked(projectFile->getCheckUnusedTemplates());
     mUI.mMaxCtuDepth->setValue(projectFile->getMaxCtuDepth());
+    mUI.mMaxTemplateRecursion->setValue(projectFile->getMaxTemplateRecursion());
     if (projectFile->clangParser)
         mUI.mBtnClangParser->setChecked(true);
     else
         mUI.mBtnCppcheckParser->setChecked(true);
     mUI.mBtnSafeClasses->setChecked(projectFile->safeChecks.classes);
-    mUI.mBugHunting->setChecked(projectFile->bugHunting);
+    mUI.mBtnBugHunting->setChecked(projectFile->bugHunting);
     setExcludedPaths(projectFile->getExcludedPaths());
     setLibraries(projectFile->getLibraries());
     const QString platform = projectFile->getPlatform();
@@ -315,7 +331,7 @@ void ProjectFileDialog::loadFromProjectFile(const ProjectFile *projectFile)
 
     // Addons..
     QSettings settings;
-    const QString dataDir = settings.value("DATADIR", QString()).toString();
+    const QString dataDir = getDataDir();
     updateAddonCheckBox(mUI.mAddonThreadSafety, projectFile, dataDir, "threadsafety");
     updateAddonCheckBox(mUI.mAddonY2038, projectFile, dataDir, "y2038");
     updateAddonCheckBox(mUI.mAddonCert, projectFile, dataDir, "cert");
@@ -339,17 +355,6 @@ void ProjectFileDialog::loadFromProjectFile(const ProjectFile *projectFile)
     }
     mUI.mEditTags->setText(projectFile->getTags().join(';'));
     updatePathsAndDefines();
-    if (mUI.mEditImportProject->text().endsWith(".sln") || mUI.mEditImportProject->text().endsWith(".vcxproj")) {
-        setVsConfigurations(getProjectConfigs(mUI.mEditImportProject->text()));
-        foreach (const QString &cfg, projectFile->getVsConfigurations()) {
-            QList<QListWidgetItem*> items = mUI.mListVsConfigs->findItems(cfg, Qt::MatchFlag::MatchExactly);
-            items[0]->setSelected(true);
-        }
-    } else {
-        mUI.mListVsConfigs->clear();
-        mUI.mListVsConfigs->setEnabled(false);
-    }
-
 }
 
 void ProjectFileDialog::saveToProjectFile(ProjectFile *projectFile) const
@@ -358,9 +363,11 @@ void ProjectFileDialog::saveToProjectFile(ProjectFile *projectFile) const
     projectFile->setBuildDir(getBuildDir());
     projectFile->setImportProject(getImportProject());
     projectFile->setAnalyzeAllVsConfigs(mUI.mChkAllVsConfigs->isChecked());
+    projectFile->setVSConfigurations(getProjectConfigurations());
     projectFile->setCheckHeaders(mUI.mCheckHeaders->isChecked());
     projectFile->setCheckUnusedTemplates(mUI.mCheckUnusedTemplates->isChecked());
     projectFile->setMaxCtuDepth(mUI.mMaxCtuDepth->value());
+    projectFile->setMaxTemplateRecursion(mUI.mMaxTemplateRecursion->value());
     projectFile->setIncludes(getIncludePaths());
     projectFile->setDefines(getDefines());
     projectFile->setUndefines(getUndefines());
@@ -369,7 +376,7 @@ void ProjectFileDialog::saveToProjectFile(ProjectFile *projectFile) const
     projectFile->setLibraries(getLibraries());
     projectFile->clangParser = mUI.mBtnClangParser->isChecked();
     projectFile->safeChecks.classes = mUI.mBtnSafeClasses->isChecked();
-    projectFile->bugHunting = mUI.mBugHunting->isChecked();
+    projectFile->bugHunting = mUI.mBtnBugHunting->isChecked();
     if (mUI.mComboBoxPlatform->currentText().endsWith(".xml"))
         projectFile->setPlatform(mUI.mComboBoxPlatform->currentText());
     else {
@@ -410,7 +417,6 @@ void ProjectFileDialog::saveToProjectFile(ProjectFile *projectFile) const
     projectFile->setClangAnalyzer(mUI.mToolClangAnalyzer->isChecked());
     projectFile->setClangTidy(mUI.mToolClangTidy->isChecked());
     projectFile->setTags(mUI.mEditTags->text().split(";", QString::SkipEmptyParts));
-    projectFile->setVSConfigurations(getVsConfigurations());
 }
 
 void ProjectFileDialog::ok()
@@ -456,6 +462,7 @@ void ProjectFileDialog::updatePathsAndDefines()
 {
     const QString &fileName = mUI.mEditImportProject->text();
     bool importProject = !fileName.isEmpty();
+    bool hasConfigs = fileName.endsWith(".sln") || fileName.endsWith(".vcxproj");
     mUI.mBtnClearImportProject->setEnabled(importProject);
     mUI.mListCheckPaths->setEnabled(!importProject);
     mUI.mListIncludeDirs->setEnabled(!importProject);
@@ -469,9 +476,9 @@ void ProjectFileDialog::updatePathsAndDefines()
     mUI.mBtnRemoveInclude->setEnabled(!importProject);
     mUI.mBtnIncludeUp->setEnabled(!importProject);
     mUI.mBtnIncludeDown->setEnabled(!importProject);
-    mUI.mChkAllVsConfigs->setEnabled(fileName.endsWith(".sln") || fileName.endsWith(".vcxproj"));
-    mUI.mListVsConfigs->setEnabled(fileName.endsWith(".sln") || fileName.endsWith(".vcxproj"));
-    if (!mUI.mListVsConfigs->isEnabled())
+    mUI.mChkAllVsConfigs->setEnabled(hasConfigs);
+    mUI.mListVsConfigs->setEnabled(hasConfigs && !mUI.mChkAllVsConfigs->isChecked());
+    if (!hasConfigs)
         mUI.mListVsConfigs->clear();
 }
 
@@ -495,24 +502,34 @@ void ProjectFileDialog::browseImportProject()
     if (!fileName.isEmpty()) {
         mUI.mEditImportProject->setText(dir.relativeFilePath(fileName));
         updatePathsAndDefines();
-        setVsConfigurations(getProjectConfigs(fileName));
-        mUI.mListVsConfigs->selectAll();
+        setProjectConfigurations(getProjectConfigs(fileName));
+        for (int row = 0; row < mUI.mListVsConfigs->count(); ++row) {
+            QListWidgetItem *item = mUI.mListVsConfigs->item(row);
+            item->setCheckState(Qt::Checked);
+        }
     }
 }
 
-QStringList ProjectFileDialog::getVsConfigurations() const
+QStringList ProjectFileDialog::getProjectConfigurations() const
 {
     QStringList configs;
-    foreach (QListWidgetItem *item, mUI.mListVsConfigs->selectedItems())
-        configs << item->text();
-
+    for (int row = 0; row < mUI.mListVsConfigs->count(); ++row) {
+        QListWidgetItem *item = mUI.mListVsConfigs->item(row);
+        if (item->checkState() == Qt::Checked)
+            configs << item->text();
+    }
     return configs;
 }
 
-void ProjectFileDialog::setVsConfigurations(const QStringList &configs)
+void ProjectFileDialog::setProjectConfigurations(const QStringList &configs)
 {
     mUI.mListVsConfigs->clear();
-    mUI.mListVsConfigs->addItems(configs);
+    mUI.mListVsConfigs->setEnabled(!configs.isEmpty() && !mUI.mChkAllVsConfigs->isChecked());
+    foreach (const QString &cfg, configs) {
+        QListWidgetItem* item = new QListWidgetItem(cfg, mUI.mListVsConfigs);
+        item->setFlags(item->flags() | Qt::ItemIsUserCheckable); // set checkable flag
+        item->setCheckState(Qt::Unchecked);
+    }
 }
 
 QString ProjectFileDialog::getImportProject() const
@@ -715,9 +732,17 @@ void ProjectFileDialog::editIncludeDir()
 
 void ProjectFileDialog::addExcludePath()
 {
-    QString dir = getExistingDirectory(tr("Select directory to ignore"), true);
-    if (!dir.isEmpty())
-        addExcludePath(dir);
+    addExcludePath(getExistingDirectory(tr("Select directory to ignore"), true));
+}
+
+void ProjectFileDialog::addExcludeFile()
+{
+    const QFileInfo inf(mProjectFile->getFilename());
+    const QDir &dir = inf.absoluteDir();
+    QMap<QString,QString> filters;
+    filters[tr("Source files")] = "*.c *.cpp";
+    filters[tr("All files")] = "*.*";
+    addExcludePath(QFileDialog::getOpenFileName(this, tr("Exclude file"), dir.canonicalPath(), toFilterString(filters)));
 }
 
 void ProjectFileDialog::editExcludePath()
@@ -800,7 +825,10 @@ int ProjectFileDialog::getSuppressionIndex(const QString &shortText) const
 
 void ProjectFileDialog::browseMisraFile()
 {
-    const QString fileName = QFileDialog::getOpenFileName(this, tr("Select MISRA rule texts file"), QDir::homePath(), tr("Misra rule texts file (%1)").arg("*.txt"));
+    const QString fileName = QFileDialog::getOpenFileName(this,
+                             tr("Select MISRA rule texts file"),
+                             QDir::homePath(),
+                             tr("Misra rule texts file (%1)").arg("*.txt"));
     if (!fileName.isEmpty()) {
         QSettings settings;
         mUI.mEditMisraFile->setText(fileName);
@@ -808,6 +836,6 @@ void ProjectFileDialog::browseMisraFile()
 
         mUI.mAddonMisra->setText("MISRA C 2012");
         mUI.mAddonMisra->setEnabled(true);
-        updateAddonCheckBox(mUI.mAddonMisra, nullptr, settings.value("DATADIR", QString()).toString(), "misra");
+        updateAddonCheckBox(mUI.mAddonMisra, nullptr, getDataDir(), "misra");
     }
 }
