@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2017 Cppcheck team.
+ * Copyright (C) 2007-2020 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,9 +22,8 @@
 #include <QString>
 #include <QList>
 #include "report.h"
-#include "erroritem.h"
 
-class QObject;
+class ErrorItem;
 
 /// @addtogroup GUI
 /// @{
