@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2019 Cppcheck team.
+ * Copyright (C) 2007-2020 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,10 +25,9 @@
 #include "check.h"
 #include "config.h"
 #include "ctu.h"
-#include "errorlogger.h"
 #include "mathlib.h"
-#include "tokenize.h"
 #include "symboldatabase.h"
+#include "valueflow.h"
 
 #include <cstddef>
 #include <list>
@@ -36,6 +35,14 @@
 #include <string>
 #include <vector>
 
+namespace tinyxml2 {
+    class XMLElement;
+}
+
+class ErrorLogger;
+class Settings;
+class Token;
+class Tokenizer;
 
 /// @addtogroup Checks
 /// @{
@@ -104,7 +111,6 @@ private:
 
     void stringNotZeroTerminated();
     void terminateStrncpyError(const Token *tok, const std::string &varname);
-    void bufferNotZeroTerminatedError(const Token *tok, const std::string &varname, const std::string &function);
 
     void objectIndex();
     void objectIndexError(const Token *tok, const ValueFlow::Value *v, bool known);
