@@ -24,6 +24,7 @@
 #include "check.h"
 #include "config.h"
 #include "tokenize.h"
+#include "symboldatabase.h"
 
 #include <list>
 #include <map>
@@ -62,7 +63,6 @@ public:
         // can't be a simplified check .. the 'sizeof' is used.
         checkClass.checkMemset();
         checkClass.constructors();
-        checkClass.operatorEq();
         checkClass.privateFunctions();
         checkClass.operatorEqRetRefThis();
         checkClass.thisSubtraction();
@@ -104,9 +104,6 @@ public:
     void checkMemset();
     void checkMemsetType(const Scope *start, const Token *tok, const Scope *type, bool allocation, std::set<const Scope *> parsedTypes);
 
-    /** @brief 'operator=' should return something and it should not be const. */
-    void operatorEq();
-
     /** @brief 'operator=' should return reference to *this */
     void operatorEqRetRefThis();    // Warning upon no "return *this;"
 
@@ -162,7 +159,7 @@ private:
     void noCopyConstructorError(const Scope *scope, bool isdefault, const Token *alloc, bool inconclusive);
     void noOperatorEqError(const Scope *scope, bool isdefault, const Token *alloc, bool inconclusive);
     void noDestructorError(const Scope *scope, bool isdefault, const Token *alloc);
-    void uninitVarError(const Token *tok, bool isprivate, const std::string &classname, const std::string &varname, bool inconclusive);
+    void uninitVarError(const Token *tok, bool isprivate, Function::Type functionType, const std::string &classname, const std::string &varname, bool inconclusive);
     void operatorEqVarError(const Token *tok, const std::string &classname, const std::string &varname, bool inconclusive);
     void unusedPrivateFunctionError(const Token *tok, const std::string &classname, const std::string &funcname);
     void memsetError(const Token *tok, const std::string &memfunc, const std::string &classname, const std::string &type);
@@ -170,7 +167,6 @@ private:
     void memsetErrorFloat(const Token *tok, const std::string &type);
     void mallocOnClassError(const Token* tok, const std::string &memfunc, const Token* classTok, const std::string &classname);
     void mallocOnClassWarning(const Token* tok, const std::string &memfunc, const Token* classTok);
-    void operatorEqReturnError(const Token *tok, const std::string &className);
     void virtualDestructorError(const Token *tok, const std::string &Base, const std::string &Derived, bool inconclusive);
     void thisSubtractionError(const Token *tok);
     void operatorEqRetRefThisError(const Token *tok);
@@ -199,8 +195,8 @@ private:
         c.noCopyConstructorError(nullptr, false, nullptr, false);
         c.noOperatorEqError(nullptr, false, nullptr, false);
         c.noDestructorError(nullptr, false, nullptr);
-        c.uninitVarError(nullptr, false, "classname", "varname", false);
-        c.uninitVarError(nullptr, true, "classname", "varnamepriv", false);
+        c.uninitVarError(nullptr, false, Function::eConstructor, "classname", "varname", false);
+        c.uninitVarError(nullptr, true, Function::eConstructor, "classname", "varnamepriv", false);
         c.operatorEqVarError(nullptr, "classname", emptyString, false);
         c.unusedPrivateFunctionError(nullptr, "classname", "funcname");
         c.memsetError(nullptr, "memfunc", "classname", "class");
@@ -208,7 +204,6 @@ private:
         c.memsetErrorFloat(nullptr, "class");
         c.mallocOnClassWarning(nullptr, "malloc", nullptr);
         c.mallocOnClassError(nullptr, "malloc", nullptr, "std::string");
-        c.operatorEqReturnError(nullptr, "class");
         c.virtualDestructorError(nullptr, "Base", "Derived", false);
         c.thisSubtractionError(nullptr);
         c.operatorEqRetRefThisError(nullptr);
@@ -244,7 +239,6 @@ private:
                "- Warn if memory for classes is allocated with malloc()\n"
                "- If it's a base class, check that the destructor is virtual\n"
                "- Are there unused private functions?\n"
-               "- 'operator=' should return reference to self\n"
                "- 'operator=' should check for assignment to self\n"
                "- Constness for member functions\n"
                "- Order of initializations\n"
