@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2019 Cppcheck team.
+ * Copyright (C) 2007-2020 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,13 +25,16 @@
 #include "check.h"
 #include "config.h"
 #include "mathlib.h"
+#include "errortypes.h"
+#include "utils.h"
 
+#include <set>
 #include <string>
 
-class ErrorLogger;
 class Settings;
 class Token;
 class Tokenizer;
+class ErrorLogger;
 
 /// @addtogroup Checks
 /// @{
