@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2019 Cppcheck team.
+ * Copyright (C) 2007-2020 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@
 
 #include "check.h"
 #include "config.h"
-#include "errorlogger.h"
+#include "errortypes.h"
 #include "tokenize.h"
 
 #include <list>
@@ -43,9 +43,9 @@
 class Function;
 class Scope;
 class Settings;
-class SymbolDatabase;
 class Token;
 class Variable;
+class ErrorLogger;
 
 /// @addtogroup Core
 /// @{
