@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2019 Cppcheck team.
+ * Copyright (C) 2007-2020 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,8 +23,13 @@
 //---------------------------------------------------------------------------
 
 #include "check.h"
+#include "errorlogger.h"
 #include "valueflow.h"
 
+#include <map>
+
+class Function;
+
 /// @addtogroup Core
 /// @{
 
@@ -79,7 +84,7 @@ namespace CTU {
             std::string callArgumentExpression;
             MathLib::bigint callArgValue;
             ValueFlow::Value::ValueType callValueType;
-            std::vector<ErrorLogger::ErrorMessage::FileLocation> callValuePath;
+            std::vector<ErrorMessage::FileLocation> callValuePath;
             bool warning;
 
             std::string toXmlString() const;
@@ -111,7 +116,7 @@ namespace CTU {
         void loadFromXml(const tinyxml2::XMLElement *xmlElement);
         std::map<std::string, std::list<const CallBase *>> getCallsMap() const;
 
-        std::list<ErrorLogger::ErrorMessage::FileLocation> getErrorPath(InvalidValueType invalidValue,
+        std::list<ErrorMessage::FileLocation> getErrorPath(InvalidValueType invalidValue,
                 const UnsafeUsage &unsafeUsage,
                 const std::map<std::string, std::list<const CallBase *>> &callsMap,
                 const char info[],
