@@ -32,6 +32,7 @@
 #include <cstdlib>
 #include <cstring>
 #include <iomanip>
+#include <functional> // std::hash
 
 InternalError::InternalError(const Token *tok, const std::string &errorMsg, Type type) :
     token(tok), errorMessage(errorMsg), type(type)
@@ -58,8 +59,15 @@ InternalError::InternalError(const Token *tok, const std::string &errorMsg, Type
     }
 }
 
+static std::size_t calculateWarningHash(const TokenList *tokenList, const std::string &msg)
+{
+    if (!tokenList)
+        return 0;
+    return std::hash<std::string> {}(msg + "\n" + tokenList->front()->stringifyList(false, true, false, false, false));
+}
+
 ErrorMessage::ErrorMessage()
-    : incomplete(false), severity(Severity::none), cwe(0U), inconclusive(false)
+    : incomplete(false), severity(Severity::none), cwe(0U), inconclusive(false), hash(0)
 {
 }
 
@@ -70,7 +78,8 @@ ErrorMessage::ErrorMessage(const std::list<FileLocation> &callStack, const std::
     incomplete(false),
     severity(severity),   // severity for this error message
     cwe(0U),
-    inconclusive(inconclusive)
+    inconclusive(inconclusive),
+    hash(0)
 {
     // set the summary and verbose messages
     setmsg(msg);
@@ -85,14 +94,15 @@ ErrorMessage::ErrorMessage(const std::list<FileLocation> &callStack, const std::
     incomplete(false),
     severity(severity),   // severity for this error message
     cwe(cwe.id),
-    inconclusive(inconclusive)
+    inconclusive(inconclusive),
+    hash(0)
 {
     // set the summary and verbose messages
     setmsg(msg);
 }
 
 ErrorMessage::ErrorMessage(const std::list<const Token*>& callstack, const TokenList* list, Severity::SeverityType severity, const std::string& id, const std::string& msg, bool inconclusive)
-    : id(id), incomplete(false), severity(severity), cwe(0U), inconclusive(inconclusive)
+    : id(id), incomplete(false), severity(severity), cwe(0U), inconclusive(inconclusive), hash(0)
 {
     // Format callstack
     for (std::list<const Token *>::const_iterator it = callstack.begin(); it != callstack.end(); ++it) {
@@ -126,15 +136,28 @@ ErrorMessage::ErrorMessage(const std::list<const Token*>& callstack, const Token
         file0 = list->getFiles()[0];
 
     setmsg(msg);
+
+    std::ostringstream hashWarning;
+    for (const Token *tok: callstack)
+        hashWarning << std::hex << (tok ? tok->index() : 0) << " ";
+    hashWarning << mShortMessage;
+
+    hash = calculateWarningHash(list, hashWarning.str());
 }
 
 ErrorMessage::ErrorMessage(const ErrorPath &errorPath, const TokenList *tokenList, Severity::SeverityType severity, const char id[], const std::string &msg, const CWE &cwe, bool inconclusive)
     : id(id), incomplete(false), severity(severity), cwe(cwe.id), inconclusive(inconclusive)
 {
     // Format callstack
-    for (ErrorPath::const_iterator it = errorPath.begin(); it != errorPath.end(); ++it) {
-        const Token *tok = it->first;
-        const std::string &info = it->second;
+    for (const ErrorPathItem& e: errorPath) {
+        const Token *tok = e.first;
+        std::string info = e.second;
+
+        if (info.compare(0,8,"$symbol:") == 0 && info.find("\n") < info.size()) {
+            const std::string::size_type pos = info.find("\n");
+            const std::string &symbolName = info.substr(8, pos - 8);
+            info = replaceStr(info.substr(pos+1), "$symbol", symbolName);
+        }
 
         // --errorlist can provide null values here
         if (tok)
@@ -145,6 +168,13 @@ ErrorMessage::ErrorMessage(const ErrorPath &errorPath, const TokenList *tokenLis
         file0 = tokenList->getFiles()[0];
 
     setmsg(msg);
+
+    std::ostringstream hashWarning;
+    for (const ErrorPathItem &e: errorPath)
+        hashWarning << std::hex << (e.first ? e.first->index() : 0) << " ";
+    hashWarning << mShortMessage;
+
+    hash = calculateWarningHash(tokenList, hashWarning.str());
 }
 
 ErrorMessage::ErrorMessage(const tinyxml2::XMLElement * const errmsg)
@@ -173,6 +203,9 @@ ErrorMessage::ErrorMessage(const tinyxml2::XMLElement * const errmsg)
     attr = errmsg->Attribute("verbose");
     mVerboseMessage = attr ? attr : "";
 
+    attr = errmsg->Attribute("hash");
+    std::istringstream(attr ? attr : "0") >> hash;
+
     for (const tinyxml2::XMLElement *e = errmsg->FirstChildElement(); e; e = e->NextSiblingElement()) {
         if (std::strcmp(e->Name(),"location")==0) {
             const char *strfile = e->Attribute("file");
@@ -218,6 +251,7 @@ void ErrorMessage::setmsg(const std::string &msg)
 Suppressions::ErrorMessage ErrorMessage::toSuppressionsErrorMessage() const
 {
     Suppressions::ErrorMessage ret;
+    ret.hash = hash;
     ret.errorId = id;
     if (!callStack.empty()) {
         ret.setFileName(callStack.back().getfile(false));
@@ -236,6 +270,7 @@ std::string ErrorMessage::serialize() const
     oss << id.length() << " " << id;
     oss << Severity::toString(severity).length() << " " << Severity::toString(severity);
     oss << MathLib::toString(cwe.id).length() << " " << MathLib::toString(cwe.id);
+    oss << MathLib::toString(hash).length() << " " << MathLib::toString(hash);
     if (inconclusive) {
         const std::string text("inconclusive");
         oss << text.length() << " " << text;
@@ -262,9 +297,9 @@ bool ErrorMessage::deserialize(const std::string &data)
     inconclusive = false;
     callStack.clear();
     std::istringstream iss(data);
-    std::array<std::string, 5> results;
+    std::array<std::string, 6> results;
     std::size_t elem = 0;
-    while (iss.good()) {
+    while (iss.good() && elem < 6) {
         unsigned int len = 0;
         if (!(iss >> len))
             return false;
@@ -282,19 +317,17 @@ bool ErrorMessage::deserialize(const std::string &data)
         }
 
         results[elem++] = temp;
-        if (elem == 5)
-            break;
     }
 
-    if (elem != 5)
+    if (elem != 6)
         throw InternalError(nullptr, "Internal Error: Deserialization of error message failed");
 
     id = results[0];
     severity = Severity::fromString(results[1]);
-    std::istringstream scwe(results[2]);
-    scwe >> cwe.id;
-    mShortMessage = results[3];
-    mVerboseMessage = results[4];
+    std::istringstream(results[2]) >> cwe.id;
+    std::istringstream(results[3]) >> hash;
+    mShortMessage = results[4];
+    mVerboseMessage = results[5];
 
     unsigned int stackSize = 0;
     if (!(iss >> stackSize))
@@ -347,8 +380,6 @@ bool ErrorMessage::deserialize(const std::string &data)
 
 std::string ErrorMessage::getXMLHeader()
 {
-    // xml_version 1 is the default xml format
-
     tinyxml2::XMLPrinter printer;
 
     // standard xml header
@@ -403,6 +434,8 @@ std::string ErrorMessage::toXML() const
     printer.PushAttribute("verbose", fixInvalidChars(mVerboseMessage).c_str());
     if (cwe.id)
         printer.PushAttribute("cwe", cwe.id);
+    if (hash)
+        printer.PushAttribute("hash", MathLib::toString(hash).c_str());
     if (inconclusive)
         printer.PushAttribute("inconclusive", "true");
 
@@ -655,6 +688,9 @@ std::string ErrorLogger::toxml(const std::string &str)
         case '\"':
             xml << "&quot;";
             break;
+        case '\'':
+            xml << "&apos;";
+            break;
         case '\0':
             xml << "\\0";
             break;
