@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2019 Cppcheck team.
+ * Copyright (C) 2007-2020 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ public:
     private:
         long long mIntValue;
         double mDoubleValue;
-        enum { INT, LONG, LONGLONG, FLOAT } mType;
+        enum class Type { INT, LONG, LONGLONG, FLOAT } mType;
         bool mIsUnsigned;
 
         void promote(const value &v);
@@ -49,10 +49,10 @@ public:
         explicit value(const std::string &s);
         std::string str() const;
         bool isInt() const {
-            return mType != FLOAT;
+            return mType != Type::FLOAT;
         }
         bool isFloat() const {
-            return mType == FLOAT;
+            return mType == Type::FLOAT;
         }
 
         double getDoubleValue() const {
