@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2019 Cppcheck team.
+ * Copyright (C) 2007-2020 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -91,6 +91,9 @@ public:
     void inlineSuppressions(const simplecpp::TokenList &tokens);
 
     void setDirectives(const simplecpp::TokenList &tokens);
+    void setDirectives(const std::list<Directive> &directives) {
+        mDirectives = directives;
+    }
 
     /** list of all directives met while preprocessing file */
     const std::list<Directive> &getDirectives() const {
