@@ -15,10 +15,13 @@ struct ProgramMemory {
     Map values;
 
     void setValue(nonneg int varid, const ValueFlow::Value &value);
+    const ValueFlow::Value* getValue(nonneg int varid) const;
 
     bool getIntValue(nonneg int varid, MathLib::bigint* result) const;
     void setIntValue(nonneg int varid, MathLib::bigint value);
 
+    bool getContainerSizeValue(nonneg int varid, MathLib::bigint* result) const;
+
     void setUnknown(nonneg int varid);
 
     bool getTokValue(nonneg int varid, const Token** result) const;
