@@ -115,6 +115,9 @@ public:
     /** Use Clang */
     bool clang;
 
+    /** Custom Clang executable */
+    std::string clangExecutable;
+
     /** Use clang-tidy */
     bool clangTidy;
 
@@ -176,6 +179,12 @@ public:
 
     std::map<std::string, std::string> functionContracts;
 
+    struct VariableContracts {
+        std::string minValue;
+        std::string maxValue;
+    };
+    std::map<std::string, VariableContracts> variableContracts;
+
     /** @brief List of include paths, e.g. "my/includes/" which should be used
         for finding include files inside source files. (-I) */
     std::list<std::string> includePaths;
@@ -202,15 +211,18 @@ public:
     Library library;
 
     /** @brief Load average value */
-    unsigned int loadAverage;
+    int loadAverage;
 
     /** @brief Maximum number of configurations to check before bailing.
         Default is 12. (--max-configs=N) */
-    unsigned int maxConfigs;
+    int maxConfigs;
 
     /** @brief --max-ctu-depth */
     int maxCtuDepth;
 
+    /** @brief max template recursion */
+    int maxTemplateRecursion;
+
     /** @brief suppress exitcode */
     Suppressions nofail;
 
