@@ -93,12 +93,22 @@ public:
         bool isSuppressed(const ErrorMessage &errmsg) const;
 
         bool isMatch(const ErrorMessage &errmsg);
+
         std::string getText() const;
 
         bool isLocal() const {
             return !fileName.empty() && fileName.find_first_of("?*") == std::string::npos;
         }
 
+        bool isSameParameters(const Suppression &other) const {
+            return errorId == other.errorId &&
+                   fileName == other.fileName &&
+                   lineNumber == other.lineNumber &&
+                   symbolName == other.symbolName &&
+                   hash == other.hash &&
+                   thisAndNextLine == other.thisAndNextLine;
+        }
+
         std::string errorId;
         std::string fileName;
         int lineNumber;
@@ -147,6 +157,13 @@ public:
      */
     std::string addSuppression(const Suppression &suppression);
 
+    /**
+     * @brief Combine list of suppressions into the current suppressions.
+     * @param suppressions list of suppression details
+     * @return error message. empty upon success
+     */
+    std::string addSuppressions(const std::list<Suppression> &suppressions);
+
     /**
      * @brief Returns true if this message should not be shown to the user.
      * @param errmsg error message
@@ -179,6 +196,12 @@ public:
      */
     std::list<Suppression> getUnmatchedGlobalSuppressions(const bool unusedFunctionChecking) const;
 
+    /**
+     * @brief Returns list of all suppressions.
+     * @return list of suppressions
+     */
+    std::list<Suppression> getSuppressions() const;
+
 private:
     /** @brief List of error which the user doesn't want to see. */
     std::list<Suppression> mSuppressions;
