@@ -433,6 +433,9 @@ public:
     bool isBoolean() const {
         return mTokType == eBoolean;
     }
+    bool isIncDecOp() const {
+        return mTokType == eIncDecOp;
+    }
     bool isBinaryOp() const {
         return astOperand1() != nullptr && astOperand2() != nullptr;
     }
@@ -850,6 +853,7 @@ public:
     struct stringifyOptions {
         bool varid = false;
         bool exprid = false;
+        bool idtype = false; // distinguish varid / exprid
         bool attributes = false;
         bool macro = false;
         bool linenumbers = false;
@@ -874,6 +878,13 @@ public:
             options.exprid = true;
             return options;
         }
+        static stringifyOptions forPrintOut() {
+            stringifyOptions options = forDebug();
+            options.exprid = true;
+            options.varid = true;
+            options.idtype = true;
+            return options;
+        }
     };
 
     /**
@@ -1340,7 +1351,7 @@ public:
 
     std::string expressionString() const;
 
-    void printAst(bool verbose, bool xml, std::ostream &out) const;
+    void printAst(bool verbose, bool xml, const std::vector<std::string> &fileNames, std::ostream &out) const;
 
     void printValueFlow(bool xml, std::ostream &out) const;
 
