@@ -51,6 +51,7 @@ private:
         TEST_CASE(functionCallInAssert);
         TEST_CASE(memberFunctionCallInAssert);
         TEST_CASE(safeFunctionCallInAssert);
+        TEST_CASE(crash);
     }
 
 
@@ -236,6 +237,13 @@ private:
               "}\n");
         ASSERT_EQUALS("", errout.str());
     }
+
+    void crash() {
+        check("void foo() {\n"
+              "  assert(sizeof(struct { int a[x++]; })==sizeof(int));\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+    }
 };
 
 REGISTER_TEST(TestAssert)
