@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2019 Cppcheck team.
+ * Copyright (C) 2007-2020 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ private:
         settings.addEnabled("style");
         settings.addEnabled("performance");
 
-        TEST_CASE(BoostForeachContainerModification)
+        TEST_CASE(BoostForeachContainerModification);
     }
 
     void check(const char code[]) {
