@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2019 Cppcheck team.
+ * Copyright (C) 2007-2020 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,6 +47,7 @@ private:
 
         TEST_CASE(isDirectory);
         TEST_CASE(recursiveAddFiles);
+        TEST_CASE(fileExists);
     }
 
     void isDirectory() const {
@@ -79,6 +80,11 @@ private:
         // Make sure headers are not added..
         ASSERT(files.find("lib/tokenize.h") == files.end());
     }
+
+    void fileExists() const {
+        ASSERT_EQUALS(false, FileLister::fileExists("lib"));
+        ASSERT_EQUALS(true, FileLister::fileExists("readme.txt"));
+    }
 };
 
 REGISTER_TEST(TestFileLister)
