@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2019 Cppcheck team.
+ * Copyright (C) 2007-2020 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,12 +42,12 @@ private:
         TEST_CASE(ispositive);
         TEST_CASE(isFloat);
         TEST_CASE(isDecimalFloat);
-        TEST_CASE(isGreater)
-        TEST_CASE(isGreaterEqual)
-        TEST_CASE(isEqual)
-        TEST_CASE(isNotEqual)
-        TEST_CASE(isLess)
-        TEST_CASE(isLessEqual)
+        TEST_CASE(isGreater);
+        TEST_CASE(isGreaterEqual);
+        TEST_CASE(isEqual);
+        TEST_CASE(isNotEqual);
+        TEST_CASE(isLess);
+        TEST_CASE(isLessEqual);
         TEST_CASE(calculate);
         TEST_CASE(calculate1);
         TEST_CASE(typesuffix);
@@ -155,6 +155,16 @@ private:
         ASSERT_EQUALS("4611686018427387904",  MathLib::divide("-9223372036854775808", "-2")); // #6679
 
 
+        // invoke for each supported action
+        ASSERT_EQUALS("3", MathLib::calculate("2", "1", '+'));
+        ASSERT_EQUALS("1", MathLib::calculate("2", "1", '-'));
+        ASSERT_EQUALS("2", MathLib::calculate("2", "1", '*'));
+        ASSERT_EQUALS("2", MathLib::calculate("2", "1", '/'));
+        ASSERT_EQUALS("0", MathLib::calculate("2", "1", '%'));
+        ASSERT_EQUALS("0", MathLib::calculate("1", "2", '&'));
+        ASSERT_EQUALS("1", MathLib::calculate("1", "1", '|'));
+        ASSERT_EQUALS("1", MathLib::calculate("0", "1", '^'));
+
         // Unknown action should throw exception
         ASSERT_THROW(MathLib::calculate("1","2",'j'),InternalError);
     }
@@ -262,6 +272,11 @@ private:
         // from binary
         ASSERT_EQUALS(0,    MathLib::toLongNumber("0b0"));
         ASSERT_EQUALS(1,    MathLib::toLongNumber("0b1"));
+        ASSERT_EQUALS(1,    MathLib::toLongNumber("0b1U"));
+        ASSERT_EQUALS(1,    MathLib::toLongNumber("0b1L"));
+        ASSERT_EQUALS(1,    MathLib::toLongNumber("0b1LU"));
+        ASSERT_EQUALS(1,    MathLib::toLongNumber("0b1LL"));
+        ASSERT_EQUALS(1,    MathLib::toLongNumber("0b1LLU"));
         ASSERT_EQUALS(1,    MathLib::toLongNumber("+0b1"));
         ASSERT_EQUALS(-1,   MathLib::toLongNumber("-0b1"));
         ASSERT_EQUALS(215,  MathLib::toLongNumber("0b11010111"));
@@ -337,6 +352,13 @@ private:
         ASSERT_EQUALS(10000U, MathLib::toULongNumber("1e4"));
         ASSERT_EQUALS(0xFF00000000000000UL, MathLib::toULongNumber("0xFF00000000000000UL"));
         ASSERT_EQUALS(0x0A00000000000000UL, MathLib::toULongNumber("0x0A00000000000000UL"));
+        ASSERT_EQUALS(0,  MathLib::toULongNumber("0b0"));
+        ASSERT_EQUALS(1,  MathLib::toULongNumber("0b1"));
+        ASSERT_EQUALS(1,  MathLib::toULongNumber("0b1U"));
+        ASSERT_EQUALS(1,  MathLib::toULongNumber("0b1L"));
+        ASSERT_EQUALS(1,  MathLib::toULongNumber("0b1LU"));
+        ASSERT_EQUALS(1,  MathLib::toULongNumber("0b1LL"));
+        ASSERT_EQUALS(1,  MathLib::toULongNumber("0b1LLU"));
         ASSERT_EQUALS(9U, MathLib::toULongNumber("011"));
         ASSERT_EQUALS(5U, MathLib::toULongNumber("0b101"));
 
@@ -351,6 +373,8 @@ private:
     }
 
     void toDoubleNumber() const {
+        ASSERT_EQUALS_DOUBLE(1.0,    MathLib::toDoubleNumber("1"),        0.001);
+        ASSERT_EQUALS_DOUBLE(1.0,    MathLib::toDoubleNumber("0x1"),      0.001);
         ASSERT_EQUALS_DOUBLE(10.0,   MathLib::toDoubleNumber("10"),       0.001);
         ASSERT_EQUALS_DOUBLE(1000.0, MathLib::toDoubleNumber("10E+2"),    0.001);
         ASSERT_EQUALS_DOUBLE(100.0,  MathLib::toDoubleNumber("1.0E+2"),   0.001);
@@ -922,6 +946,8 @@ private:
         ASSERT_EQUALS(true, MathLib::isNullValue("0x0"));
         ASSERT_EQUALS(true, MathLib::isNullValue("+0x0"));
         ASSERT_EQUALS(true, MathLib::isNullValue("-0x0"));
+        ASSERT_EQUALS(true, MathLib::isNullValue("+0X0"));
+        ASSERT_EQUALS(true, MathLib::isNullValue("-0X0"));
         // unsigned integer zero value
         ASSERT_EQUALS(true, MathLib::isNullValue("0U"));
         ASSERT_EQUALS(true, MathLib::isNullValue("+0U"));
@@ -980,6 +1006,8 @@ private:
         ASSERT_EQUALS(true, MathLib::isNullValue("0E0"));
         ASSERT_EQUALS(true, MathLib::isNullValue("+0E0"));
         ASSERT_EQUALS(true, MathLib::isNullValue("-0E0"));
+        ASSERT_EQUALS(true, MathLib::isNullValue("+0e0"));
+        ASSERT_EQUALS(true, MathLib::isNullValue("-0e0"));
         // integer scientific notation
         ASSERT_EQUALS(true, MathLib::isNullValue("0E1"));
         ASSERT_EQUALS(true, MathLib::isNullValue("+0E1"));
@@ -1042,6 +1070,7 @@ private:
         ASSERT_EQUALS(true, MathLib::isNullValue("-0.f"));
         // floating point scientific notation (suffix f)
         ASSERT_EQUALS(true, MathLib::isNullValue("0.0f"));
+        ASSERT_EQUALS(true, MathLib::isNullValue("0.0F"));
         ASSERT_EQUALS(true, MathLib::isNullValue("+0.0f"));
         ASSERT_EQUALS(true, MathLib::isNullValue("-0.0f"));
         // floating point scientific notation (suffix f)
@@ -1056,6 +1085,12 @@ private:
         ASSERT_EQUALS(true, MathLib::isNullValue("00.00E+1f"));
         ASSERT_EQUALS(true, MathLib::isNullValue("+00.00E+1f"));
         ASSERT_EQUALS(true, MathLib::isNullValue("-00.00E+1f"));
+        // hex float
+        ASSERT_EQUALS(true, MathLib::isNullValue("0x0p3"));
+        ASSERT_EQUALS(true, MathLib::isNullValue("0X0P3"));
+        ASSERT_EQUALS(true, MathLib::isNullValue("0X0p-3"));
+        ASSERT_EQUALS(true, MathLib::isNullValue("-0x0p3"));
+        ASSERT_EQUALS(true, MathLib::isNullValue("+0x0p3"));
 
         // binary numbers
         ASSERT_EQUALS(true, MathLib::isNullValue("0b00"));
@@ -1069,6 +1104,18 @@ private:
         ASSERT_EQUALS(false, MathLib::isNullValue("0.1"));
         ASSERT_EQUALS(false, MathLib::isNullValue("1.0"));
         ASSERT_EQUALS(false, MathLib::isNullValue("0.01"));
+        ASSERT_EQUALS(false, MathLib::isNullValue("0xF"));
+        ASSERT_EQUALS(false, MathLib::isNullValue("0XFF"));
+        ASSERT_EQUALS(false, MathLib::isNullValue("0b01"));
+        ASSERT_EQUALS(false, MathLib::isNullValue("0B01"));
+        ASSERT_EQUALS(false, MathLib::isNullValue("0x1p0"));
+        ASSERT_EQUALS(false, MathLib::isNullValue("0x1P0"));
+        ASSERT_EQUALS(false, MathLib::isNullValue("0xap0"));
+        ASSERT_EQUALS(false, MathLib::isNullValue("0xbp0"));
+        ASSERT_EQUALS(false, MathLib::isNullValue("0xcp0"));
+        ASSERT_EQUALS(false, MathLib::isNullValue("0xdp0"));
+        ASSERT_EQUALS(false, MathLib::isNullValue("0xep0"));
+        ASSERT_EQUALS(false, MathLib::isNullValue("0xfp0"));
         ASSERT_EQUALS(false, MathLib::isNullValue("-00.01e-12"));
         ASSERT_EQUALS(false, MathLib::isNullValue("-00.01e+12"));
         ASSERT_EQUALS(false, MathLib::isNullValue(""));
@@ -1076,6 +1123,7 @@ private:
         ASSERT_EQUALS(false, MathLib::isNullValue("x"));
         ASSERT_EQUALS(false, MathLib::isNullValue("garbage"));
         ASSERT_EQUALS(false, MathLib::isNullValue("UL"));
+        ASSERT_EQUALS(false, MathLib::isNullValue("-ENOMEM"));
     }
 
     void incdec() const {
@@ -1109,13 +1157,15 @@ private:
         ASSERT_EQUALS("0.0", MathLib::tan("0"));
     }
     void abs() const {
-        ASSERT_EQUALS("0.0", MathLib::abs("0"));
-        ASSERT_EQUALS("0.0", MathLib::abs("+0"));
-        ASSERT_EQUALS("0.0", MathLib::abs("-0"));
-        ASSERT_EQUALS("1.0", MathLib::abs("+1"));
-        ASSERT_EQUALS("1.0", MathLib::abs("+1.0"));
-        ASSERT_EQUALS("1.0", MathLib::abs("-1"));
+        ASSERT_EQUALS("", MathLib::abs(""));
+        ASSERT_EQUALS("0", MathLib::abs("0"));
+        ASSERT_EQUALS("+0", MathLib::abs("+0"));
+        ASSERT_EQUALS("0", MathLib::abs("-0"));
+        ASSERT_EQUALS("+1", MathLib::abs("+1"));
+        ASSERT_EQUALS("+1.0", MathLib::abs("+1.0"));
+        ASSERT_EQUALS("1", MathLib::abs("-1"));
         ASSERT_EQUALS("1.0", MathLib::abs("-1.0"));
+        ASSERT_EQUALS("9007199254740991", MathLib::abs("9007199254740991"));
     }
 
     void toString() const {
